@@ -7,30 +7,18 @@ from calendar import timegm
 from datetime import datetime
 from typing import Any
 
-from .exceptions import NoDevice
+from pyatmo.const import RawData
+from pyatmo.exceptions import NoDevice
 
 LOG: logging.Logger = logging.getLogger(__name__)
 
-_BASE_URL: str = "https://api.netatmo.com/"
-
-ERRORS: dict[int, str] = {
-    400: "Bad request",
-    401: "Unauthorized",
-    403: "Forbidden",
-    404: "Not found",
-    406: "Not Acceptable",
-    500: "Internal Server Error",
-    502: "Bad Gateway",
-    503: "Service Unavailable",
-}
-
 
 def to_time_string(value: str) -> str:
     return datetime.utcfromtimestamp(int(value)).isoformat(sep="_")
 
 
 def to_epoch(value: str) -> int:
-    return timegm(time.strptime(value + "GMT", "%Y-%m-%d_%H:%M:%S%Z"))
+    return timegm(time.strptime(f"{value}GMT", "%Y-%m-%d_%H:%M:%S%Z"))
 
 
 def today_stamps() -> tuple[int, int]:
@@ -38,12 +26,14 @@ def today_stamps() -> tuple[int, int]:
     return today, today + 3600 * 24
 
 
-def fix_id(raw_data: dict) -> dict:
+def fix_id(raw_data: RawData) -> dict[str, Any]:
     """Fix known errors in station ids like superfluous spaces."""
     if not raw_data:
         return raw_data
 
     for station in raw_data:
+        if not isinstance(station, dict):
+            continue
         if "_id" not in station:
             continue
 
@@ -55,7 +45,7 @@ def fix_id(raw_data: dict) -> dict:
     return raw_data
 
 
-def extract_raw_data(resp: Any, tag: str) -> dict:
+def extract_raw_data(resp: Any, tag: str) -> dict[str, Any]:
     """Extract raw data from server response."""
     if (
         resp is None
@@ -73,8 +63,13 @@ def extract_raw_data(resp: Any, tag: str) -> dict:
     return raw_data
 
 
-def extract_raw_data_new(resp: Any, tag: str) -> dict:
+def extract_raw_data_new(resp: Any, tag: str) -> dict[str, Any]:
     """Extract raw data from server response."""
+    raw_data = {}
+
+    if tag == "body":
+        return {"public": resp["body"], "errors": []}
+
     if resp is None or "body" not in resp or tag not in resp["body"]:
         LOG.debug("Server response: %s", resp)
         raise NoDevice("No device found, errors in response")
