@@ -1,33 +1,35 @@
 """Support for Netatmo energy devices (relays, thermostats and valves)."""
+from __future__ import annotations
+
 import logging
 from abc import ABC
 from collections import defaultdict
-from typing import Any, Dict, Optional
+from typing import Any
 
-from .auth import AbstractAsyncAuth, NetatmoOAuth2
-from .exceptions import InvalidRoom, NoDevice, NoSchedule
-from .helpers import _BASE_URL
+from pyatmo.auth import AbstractAsyncAuth, NetatmoOAuth2
+from pyatmo.const import (
+    GETHOMESDATA_ENDPOINT,
+    GETHOMESTATUS_ENDPOINT,
+    SETROOMTHERMPOINT_ENDPOINT,
+    SETTHERMMODE_ENDPOINT,
+    SWITCHHOMESCHEDULE_ENDPOINT,
+)
+from pyatmo.exceptions import InvalidRoom, NoSchedule
+from pyatmo.helpers import extract_raw_data
 
 LOG = logging.getLogger(__name__)
 
-_GETHOMESDATA_REQ = _BASE_URL + "api/homesdata"
-_GETHOMESTATUS_REQ = _BASE_URL + "api/homestatus"
-_SETTHERMMODE_REQ = _BASE_URL + "api/setthermmode"
-_SETROOMTHERMPOINT_REQ = _BASE_URL + "api/setroomthermpoint"
-_GETROOMMEASURE_REQ = _BASE_URL + "api/getroommeasure"
-_SWITCHHOMESCHEDULE_REQ = _BASE_URL + "api/switchhomeschedule"
-
 
 class AbstractHomeData(ABC):
     """Abstract class of Netatmo energy devices."""
 
-    raw_data: Dict = defaultdict(dict)
-    homes: Dict = defaultdict(dict)
-    modules: Dict = defaultdict(dict)
-    rooms: Dict = defaultdict(dict)
-    schedules: Dict = defaultdict(dict)
-    zones: Dict = defaultdict(dict)
-    setpoint_duration: Dict = defaultdict(dict)
+    raw_data: dict = defaultdict(dict)
+    homes: dict = defaultdict(dict)
+    modules: dict = defaultdict(dict)
+    rooms: dict = defaultdict(dict)
+    schedules: dict = defaultdict(dict)
+    zones: dict = defaultdict(dict)
+    setpoint_duration: dict = defaultdict(dict)
 
     def process(self) -> None:
         """Process data from API."""
@@ -35,9 +37,8 @@ class AbstractHomeData(ABC):
 
         for item in self.raw_data:
             home_id = item.get("id")
-            home_name = item.get("name")
 
-            if not home_name:
+            if not (home_name := item.get("name")):
                 home_name = "Unknown"
                 self.homes[home_id]["name"] = home_name
 
@@ -64,37 +65,42 @@ class AbstractHomeData(ABC):
                 for zone in schedule["zones"]:
                     self.zones[home_id][schedule_id][zone["id"]] = zone
 
-    def _get_selected_schedule(self, home_id: str) -> Dict:
+    def _get_selected_schedule(self, home_id: str) -> dict:
         """Get the selected schedule for a given home ID."""
-        for value in self.schedules.get(home_id, {}).values():
-            if "selected" in value.keys():
-                return value
+        return next(
+            (
+                value
+                for value in self.schedules.get(home_id, {}).values()
+                if "selected" in value.keys()
+            ),
+            {},
+        )
 
-        return {}
-
-    def get_hg_temp(self, home_id: str) -> Optional[float]:
+    def get_hg_temp(self, home_id: str) -> float | None:
         """Return frost guard temperature value."""
         return self._get_selected_schedule(home_id).get("hg_temp")
 
-    def get_away_temp(self, home_id: str) -> Optional[float]:
+    def get_away_temp(self, home_id: str) -> float | None:
         """Return the configured away temperature value."""
         return self._get_selected_schedule(home_id).get("away_temp")
 
-    def get_thermostat_type(self, home_id: str, room_id: str) -> Optional[str]:
+    def get_thermostat_type(self, home_id: str, room_id: str) -> str | None:
         """Return the thermostat type of the room."""
-        for module in self.modules.get(home_id, {}).values():
-            if module.get("room_id") == room_id:
-                return module.get("type")
-
-        return None
+        return next(
+            (
+                module.get("type")
+                for module in self.modules.get(home_id, {}).values()
+                if module.get("room_id") == room_id
+            ),
+            None,
+        )
 
     def is_valid_schedule(self, home_id: str, schedule_id: str):
         """Check if valid schedule."""
-        schedules = {
-            self.schedules[home_id][s]["name"]: self.schedules[home_id][s]["id"]
-            for s in self.schedules.get(home_id, {})
-        }
-        return schedule_id in list(schedules.values())
+        schedules = (
+            self.schedules[home_id][s]["id"] for s in self.schedules.get(home_id, {})
+        )
+        return schedule_id in schedules
 
 
 class HomeData(AbstractHomeData):
@@ -104,29 +110,27 @@ class HomeData(AbstractHomeData):
         """Initialize the Netatmo home data.
 
         Arguments:
-            auth {NetatmoOAuth2} -- Authentication information with a valid access token
+            auth {NetatmoOAuth2} -- Authentication information with valid access token
         """
         self.auth = auth
 
     def update(self) -> None:
         """Fetch and process data from API."""
-        resp = self.auth.post_request(url=_GETHOMESDATA_REQ)
-        if resp is None or "body" not in resp:
-            raise NoDevice("No thermostat data returned by Netatmo server")
-
-        self.raw_data = resp["body"].get("homes")
-        if not self.raw_data:
-            raise NoDevice("No thermostat data available")
+        resp = self.auth.post_api_request(endpoint=GETHOMESDATA_ENDPOINT)
 
+        self.raw_data = extract_raw_data(resp.json(), "homes")
         self.process()
 
     def switch_home_schedule(self, home_id: str, schedule_id: str) -> Any:
         """Switch the schedule for a give home ID."""
         if not self.is_valid_schedule(home_id, schedule_id):
-            raise NoSchedule("%s is not a valid schedule id" % schedule_id)
+            raise NoSchedule(f"{schedule_id} is not a valid schedule id")
 
         post_params = {"home_id": home_id, "schedule_id": schedule_id}
-        resp = self.auth.post_request(url=_SWITCHHOMESCHEDULE_REQ, params=post_params)
+        resp = self.auth.post_api_request(
+            endpoint=SWITCHHOMESCHEDULE_ENDPOINT,
+            params=post_params,
+        )
         LOG.debug("Response: %s", resp)
 
 
@@ -137,31 +141,26 @@ class AsyncHomeData(AbstractHomeData):
         """Initialize the Netatmo home data.
 
         Arguments:
-            auth {AbstractAsyncAuth} -- Authentication information with a valid access token
+            auth {AbstractAsyncAuth} -- Authentication information with valid access token
         """
         self.auth = auth
 
     async def async_update(self):
         """Fetch and process data from API."""
-        resp = await self.auth.async_post_request(url=_GETHOMESDATA_REQ)
-        if resp is None or "body" not in resp:
-            raise NoDevice("No thermostat data returned by Netatmo server")
-
-        self.raw_data = resp["body"].get("homes")
-        if not self.raw_data:
-            raise NoDevice("No thermostat data available")
+        resp = await self.auth.async_post_api_request(endpoint=GETHOMESDATA_ENDPOINT)
 
+        assert not isinstance(resp, bytes)
+        self.raw_data = extract_raw_data(await resp.json(), "homes")
         self.process()
 
-    async def async_switch_home_schedule(self, home_id: str, schedule_id: str) -> Any:
+    async def async_switch_home_schedule(self, home_id: str, schedule_id: str) -> None:
         """Switch the schedule for a give home ID."""
         if not self.is_valid_schedule(home_id, schedule_id):
-            raise NoSchedule("%s is not a valid schedule id" % schedule_id)
+            raise NoSchedule(f"{schedule_id} is not a valid schedule id")
 
-        post_params = {"home_id": home_id, "schedule_id": schedule_id}
-        resp = await self.auth.async_post_request(
-            url=_SWITCHHOMESCHEDULE_REQ,
-            params=post_params,
+        resp = await self.auth.async_post_api_request(
+            endpoint=SWITCHHOMESCHEDULE_ENDPOINT,
+            params={"home_id": home_id, "schedule_id": schedule_id},
         )
         LOG.debug("Response: %s", resp)
 
@@ -169,11 +168,11 @@ class AsyncHomeData(AbstractHomeData):
 class AbstractHomeStatus(ABC):
     """Abstract class of the Netatmo home status."""
 
-    raw_data: Dict = defaultdict(dict)
-    rooms: Dict = defaultdict(dict)
-    thermostats: Dict = defaultdict(dict)
-    valves: Dict = defaultdict(dict)
-    relays: Dict = defaultdict(dict)
+    raw_data: dict = defaultdict(dict)
+    rooms: dict = defaultdict(dict)
+    thermostats: dict = defaultdict(dict)
+    valves: dict = defaultdict(dict)
+    relays: dict = defaultdict(dict)
 
     def process(self) -> None:
         """Process data from API."""
@@ -181,60 +180,60 @@ class AbstractHomeStatus(ABC):
             self.rooms[room["id"]] = room
 
         for module in self.raw_data.get("modules", []):
-            if module["type"] == "NATherm1":
+            if module["type"] in {"NATherm1", "OTM"}:
                 self.thermostats[module["id"]] = module
 
             elif module["type"] == "NRV":
                 self.valves[module["id"]] = module
 
-            elif module["type"] == "NAPlug":
+            elif module["type"] in {"OTH", "NAPlug"}:
                 self.relays[module["id"]] = module
 
-    def get_room(self, room_id: str) -> Dict:
+    def get_room(self, room_id: str) -> dict:
         """Return room data for a given room id."""
-        for key, value in self.rooms.items():
+        for value in self.rooms.values():
             if value["id"] == room_id:
-                return self.rooms[key]
+                return value
 
-        raise InvalidRoom("No room with ID %s" % room_id)
+        raise InvalidRoom(f"No room with ID {room_id}")
 
-    def get_thermostat(self, room_id: str) -> Dict:
+    def get_thermostat(self, room_id: str) -> dict:
         """Return thermostat data for a given room id."""
-        for key, value in self.thermostats.items():
+        for value in self.thermostats.values():
             if value["id"] == room_id:
-                return self.thermostats[key]
+                return value
 
-        raise InvalidRoom("No room with ID %s" % room_id)
+        raise InvalidRoom(f"No room with ID {room_id}")
 
-    def get_relay(self, room_id: str) -> Dict:
+    def get_relay(self, room_id: str) -> dict:
         """Return relay data for a given room id."""
-        for key, value in self.relays.items():
+        for value in self.relays.values():
             if value["id"] == room_id:
-                return self.relays[key]
+                return value
 
-        raise InvalidRoom("No room with ID %s" % room_id)
+        raise InvalidRoom(f"No room with ID {room_id}")
 
-    def get_valve(self, room_id: str) -> Dict:
+    def get_valve(self, room_id: str) -> dict:
         """Return valve data for a given room id."""
-        for key, value in self.valves.items():
+        for value in self.valves.values():
             if value["id"] == room_id:
-                return self.valves[key]
+                return value
 
-        raise InvalidRoom("No room with ID %s" % room_id)
+        raise InvalidRoom(f"No room with ID {room_id}")
 
-    def set_point(self, room_id: str) -> Optional[float]:
+    def set_point(self, room_id: str) -> float | None:
         """Return the setpoint of a given room."""
         return self.get_room(room_id).get("therm_setpoint_temperature")
 
-    def set_point_mode(self, room_id: str) -> Optional[str]:
+    def set_point_mode(self, room_id: str) -> str | None:
         """Return the setpointmode of a given room."""
         return self.get_room(room_id).get("therm_setpoint_mode")
 
-    def measured_temperature(self, room_id: str) -> Optional[float]:
+    def measured_temperature(self, room_id: str) -> float | None:
         """Return the measured temperature of a given room."""
         return self.get_room(room_id).get("therm_measured_temperature")
 
-    def boiler_status(self, module_id: str) -> Optional[bool]:
+    def boiler_status(self, module_id: str) -> bool | None:
         """Return the status of the boiler status."""
         return self.get_thermostat(module_id).get("boiler_status")
 
@@ -250,25 +249,16 @@ class HomeStatus(AbstractHomeStatus):
             home_id {str} -- ID for targeted home
         """
         self.auth = auth
-
         self.home_id = home_id
 
     def update(self) -> None:
         """Fetch and process data from API."""
-        post_params = {"home_id": self.home_id}
-
-        resp = self.auth.post_request(url=_GETHOMESTATUS_REQ, params=post_params)
-        if (
-            "errors" in resp
-            or "body" not in resp
-            or "home" not in resp["body"]
-            or ("errors" in resp["body"] and "modules" not in resp["body"]["home"])
-        ):
-            LOG.error("Errors in response: %s", resp)
-            raise NoDevice("No device found, errors in response")
-
-        self.raw_data = resp["body"]["home"]
+        resp = self.auth.post_api_request(
+            endpoint=GETHOMESTATUS_ENDPOINT,
+            params={"home_id": self.home_id},
+        )
 
+        self.raw_data = extract_raw_data(resp.json(), "home")
         self.process()
 
     def set_thermmode(
@@ -276,16 +266,19 @@ class HomeStatus(AbstractHomeStatus):
         mode: str,
         end_time: int = None,
         schedule_id: str = None,
-    ) -> Optional[str]:
+    ) -> str | None:
         """Set thermotat mode."""
         post_params = {"home_id": self.home_id, "mode": mode}
-        if end_time is not None and mode in ("hg", "away"):
+        if end_time is not None and mode in {"hg", "away"}:
             post_params["endtime"] = str(end_time)
 
         if schedule_id is not None and mode == "schedule":
             post_params["schedule_id"] = schedule_id
 
-        return self.auth.post_request(url=_SETTHERMMODE_REQ, params=post_params)
+        return self.auth.post_api_request(
+            endpoint=SETTHERMMODE_ENDPOINT,
+            params=post_params,
+        ).json()
 
     def set_room_thermpoint(
         self,
@@ -293,10 +286,10 @@ class HomeStatus(AbstractHomeStatus):
         mode: str,
         temp: float = None,
         end_time: int = None,
-    ) -> Optional[str]:
+    ) -> str | None:
         """Set room themperature set point."""
         post_params = {"home_id": self.home_id, "room_id": room_id, "mode": mode}
-        # Temp and endtime should only be send when mode=='manual', but netatmo api can
+        # Temp and endtime should only be sent when mode=='manual', but netatmo api can
         # handle that even when mode == 'home' and these settings don't make sense
         if temp is not None:
             post_params["temp"] = str(temp)
@@ -304,7 +297,10 @@ class HomeStatus(AbstractHomeStatus):
         if end_time is not None:
             post_params["endtime"] = str(end_time)
 
-        return self.auth.post_request(url=_SETROOMTHERMPOINT_REQ, params=post_params)
+        return self.auth.post_api_request(
+            endpoint=SETROOMTHERMPOINT_ENDPOINT,
+            params=post_params,
+        ).json()
 
 
 class AsyncHomeStatus(AbstractHomeStatus):
@@ -318,28 +314,17 @@ class AsyncHomeStatus(AbstractHomeStatus):
             home_id {str} -- ID for targeted home
         """
         self.auth = auth
-
         self.home_id = home_id
 
     async def async_update(self) -> None:
         """Fetch and process data from API."""
-        post_params = {"home_id": self.home_id}
-
-        resp = await self.auth.async_post_request(
-            url=_GETHOMESTATUS_REQ,
-            params=post_params,
+        resp = await self.auth.async_post_api_request(
+            endpoint=GETHOMESTATUS_ENDPOINT,
+            params={"home_id": self.home_id},
         )
-        if (
-            "errors" in resp
-            or "body" not in resp
-            or "home" not in resp["body"]
-            or ("errors" in resp["body"] and "modules" not in resp["body"]["home"])
-        ):
-            LOG.error("Errors in response: %s", resp)
-            raise NoDevice("No device found, errors in response")
-
-        self.raw_data = resp["body"]["home"]
 
+        assert not isinstance(resp, bytes)
+        self.raw_data = extract_raw_data(await resp.json(), "home")
         self.process()
 
     async def async_set_thermmode(
@@ -347,19 +332,21 @@ class AsyncHomeStatus(AbstractHomeStatus):
         mode: str,
         end_time: int = None,
         schedule_id: str = None,
-    ) -> Optional[str]:
+    ) -> str | None:
         """Set thermotat mode."""
         post_params = {"home_id": self.home_id, "mode": mode}
-        if end_time is not None and mode in ("hg", "away"):
+        if end_time is not None and mode in {"hg", "away"}:
             post_params["endtime"] = str(end_time)
 
         if schedule_id is not None and mode == "schedule":
             post_params["schedule_id"] = schedule_id
 
-        return await self.auth.async_post_request(
-            url=_SETTHERMMODE_REQ,
+        resp = await self.auth.async_post_api_request(
+            endpoint=SETTHERMMODE_ENDPOINT,
             params=post_params,
         )
+        assert not isinstance(resp, bytes)
+        return await resp.json()
 
     async def async_set_room_thermpoint(
         self,
@@ -367,10 +354,10 @@ class AsyncHomeStatus(AbstractHomeStatus):
         mode: str,
         temp: float = None,
         end_time: int = None,
-    ) -> Optional[str]:
+    ) -> str | None:
         """Set room themperature set point."""
         post_params = {"home_id": self.home_id, "room_id": room_id, "mode": mode}
-        # Temp and endtime should only be send when mode=='manual', but netatmo api can
+        # Temp and endtime should only be sent when mode=='manual', but netatmo api can
         # handle that even when mode == 'home' and these settings don't make sense
         if temp is not None:
             post_params["temp"] = str(temp)
@@ -378,7 +365,9 @@ class AsyncHomeStatus(AbstractHomeStatus):
         if end_time is not None:
             post_params["endtime"] = str(end_time)
 
-        return await self.auth.async_post_request(
-            url=_SETROOMTHERMPOINT_REQ,
+        resp = await self.auth.async_post_api_request(
+            endpoint=SETROOMTHERMPOINT_ENDPOINT,
             params=post_params,
         )
+        assert not isinstance(resp, bytes)
+        return await resp.json()
